@@ -7,7 +7,10 @@ tframe.its <- function (x) {
   }
 
 tfUnSet.its <- function(x)      {x@.Data}
-tfSet.itstframe <- function(value, x) {its:::its(x, value)}
+tfSet.itstframe <- function(value, x) {
+   class(value) <- class(value)[class(value) != "itstframe"]
+   its:::its(x, value)
+   }
 
 "seriesNames<-.its" <- function (x, value) 
   {if (is.matrix(x)) dimnames(x) <- list(NULL, value)
@@ -16,13 +19,14 @@ tfSet.itstframe <- function(value, x) {its:::its(x, value)}
   }
 
 tfstart.its <- function(x) its:::dates(x)[1] # start(x) returns character rather than a date
-tfend.its   <- function(x) its:::dates(x)[periods(x)]
+tfend.its   <- function(x) its:::dates(x)[Tobs(x)]
 time.its    <- function(x, ...) its:::dates(x, ...)
 
+Tobs.its <- function(x)  NROW(x)
+
 tfstart.itstframe <- function(x) x[1]
 tfend.itstframe   <- function(x) x[length(x)]
-tfperiods.itstframe   <- function(x) length(x)
-periods.itstframe     <- function(x) length(x)
+Tobs.itstframe     <- function(x) length(x)
 
 tfwindow.its <- function(x, tf=NULL, start=tfstart(tf), end=tfend(tf), warn=TRUE)
   {# With the default warn=T warnings will be issued if no truncation takes
@@ -32,7 +36,7 @@ tfwindow.its <- function(x, tf=NULL, start=tfstart(tf), end=tfend(tf), warn=TRUE
       on.exit(options(opts))
      }
    d <- its:::dates(x)
-   i <- rep(TRUE, periods(x))
+   i <- rep(TRUE, Tobs(x))
    if(!is.null(start)) i <- i &  
              (d >= if(is.character(start)) as.POSIXct(start) else start)
    if(!is.null(end))   i <- i &  
@@ -47,7 +51,7 @@ tbind.its <- function(x, ..., pad.start=TRUE, pad.end=TRUE, warn=TRUE)
   for (z in list(...)) {
     if (!is.null(z)) {
       nm <- c(nm, seriesNames(z))
-      x <- union(x, z)
+      x <- its:::union(x, z)
       }
     }
   if (!pad.start | !pad.end)
